# martypy
Python library to communicate with Marty the Robot V1 and V2 by Robotical

[See the API Documentation](build/docs/content/docs/api-documentation.md)

To regenerate documentation:
- pip install -r dev-requirements.txt
- pydoc-markdown --server --open
